.. Matthew Henderson, 18 December 2010
   Last updated Sat Sep 14 18:21:07 BST 2013.

Introduction
============

Ryser is a Python package for modelling latin squares and related combinatorial
designs. The author is especially interested in specializations of latin
squares, notably Gerechte designs and Sudoku puzzles. Other structures of 
interest are Room squares and magic squares.

In fact, as well as providing models, and thus exposing the algorithms of
those different domains, we also provide direct access to the structures,
thus enabling the construction of direct algorithms.


